==> members-facade-2.0.1-vg-20231023.103832-7-sources.jar: com/bizvane/members/facade/service/api/IntegralChangeApiService.java <==
package com.bizvane.members.facade.service.api;

import com.bizvane.members.facade.service.card.request.IntegralChangeForTmallReqVo;
import com.bizvane.members.facade.service.card.request.IntegralChangeRequestModel;
import com.bizvane.members.facade.service.card.response.IntegralChangeResponseModel;
import com.bizvane.members.facade.vo.BatchUpdateMemberIntegralVO;
import com.bizvane.members.facade.vo.SyncIntegralVo;
import com.bizvane.utils.responseinfo.ResponseData;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

/**
 * @Author: Hou Hong Bin
 * @CreateTime: 2018/8/18.
 */
@FeignClient(value = "${feign.client.members.name}",path = "${feign.client.members.path}")
public interface IntegralChangeApiService {
    /**
     * 积分变动操作
     * @param integralChangeRequestModel
     * @return
     */
    @RequestMapping(value = "/api/integralChangeOperate", method = RequestMethod.POST)
    public IntegralChangeResponseModel integralChangeOperate(@RequestBody IntegralChangeRequestModel integralChangeRequestModel);

    /**
     * 积分变动操作
     * @param vo
     * @return
     */
    @RequestMapping(value = "/api/integralChangeOperateForTmall", method = RequestMethod.POST)
    public IntegralChangeResponseModel integralChangeOperateForTmall(@RequestBody IntegralChangeForTmallReqVo vo);

    /**
     * 线下积分流水同步到线上
     * @param vo
     * @return
     */
    @RequestMapping(value = "/api/offlineSyncIntegral", method = RequestMethod.POST)
    ResponseData offlineSyncIntegral(@RequestBody SyncIntegralVo vo);

    /**
     * 补数据使用
     * @param syncIntegralVo
     * @return
     */
    @RequestMapping(value = "/api/offlineSyncIntegralConsume", method = RequestMethod.POST)
    ResponseData offlineSyncIntegralConsume(@RequestBody SyncIntegralVo syncIntegralVo);

    /**
     * 百胜积分流水同步线上
     * @param vo
     * @return
     */
    @RequestMapping(value = "/api/baisonSyncIntegralRecord", method = RequestMethod.POST)
    ResponseData baisonSyncIntegralRecord(@RequestBody SyncIntegralVo vo);



    /**
     * 批量调整积分
     */
    @RequestMapping(value = "/api/batchChangeIntegral", method = RequestMethod.POST)
    ResponseData<String> batchChangeIntegral(@RequestBody BatchUpdateMemberIntegralVO batchUpdateMemberIntegralVO);
}

==> members-facade-2.0.2-vg-20251030.090224-15-sources.jar: com/bizvane/members/facade/service/api/IntegralChangeApiService.java <==
package com.bizvane.members.facade.service.api;

import com.bizvane.couponfacade.models.vo.SendCouponQuotaBatchRequestVO;
import com.bizvane.members.facade.service.card.request.IntegralChangeForTmallReqVo;
import com.bizvane.members.facade.service.card.request.IntegralChangeRequestModel;
import com.bizvane.members.facade.service.card.response.IntegralChangeResponseModel;
import com.bizvane.members.facade.vo.BatchChangeIntegralFromGiftBagVO;
import com.bizvane.members.facade.vo.BatchUpdateMemberIntegralVO;
import com.bizvane.members.facade.vo.SyncIntegralVo;
import com.bizvane.utils.responseinfo.ResponseData;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

/**
 * @Author: Hou Hong Bin
 * @CreateTime: 2018/8/18.
 */
@FeignClient(value = "${feign.client.members.name}",path = "${feign.client.members.path}")
public interface IntegralChangeApiService {
    /**
     * 积分变动操作
     * @param integralChangeRequestModel
     * @return
     */
    @RequestMapping(value = "/api/integralChangeOperate", method = RequestMethod.POST)
    public IntegralChangeResponseModel integralChangeOperate(@RequestBody IntegralChangeRequestModel integralChangeRequestModel);

    /**
     * 积分变动操作
     * @param vo
     * @return
     */
    @RequestMapping(value = "/api/integralChangeOperateForTmall", method = RequestMethod.POST)
    public IntegralChangeResponseModel integralChangeOperateForTmall(@RequestBody IntegralChangeForTmallReqVo vo);

    /**
     * 线下积分流水同步到线上
     * @param vo
     * @return
     */
    @RequestMapping(value = "/api/offlineSyncIntegral", method = RequestMethod.POST)
    ResponseData offlineSyncIntegral(@RequestBody SyncIntegralVo vo);

    /**
     * 补数据使用
     * @param syncIntegralVo
     * @return
     */
    @RequestMapping(value = "/api/offlineSyncIntegralConsume", method = RequestMethod.POST)
    ResponseData offlineSyncIntegralConsume(@RequestBody SyncIntegralVo syncIntegralVo);

    /**
     * 百胜积分流水同步线上
     * @param vo
     * @return
     */
    @RequestMapping(value = "/api/baisonSyncIntegralRecord", method = RequestMethod.POST)
    ResponseData baisonSyncIntegralRecord(@RequestBody SyncIntegralVo vo);



    /**
     * 批量调整积分(券包)
     */
    @RequestMapping(value = "/api/batchChangeIntegralFromGiftBag", method = RequestMethod.POST)
    ResponseData<String> batchChangeIntegralFromGiftBag(@RequestBody BatchChangeIntegralFromGiftBagVO batchChangeIntegralFromGiftBagVO);
}
